@@ -4,8 +4,8 @@ import pandas as pd
 from trell import aws
 import mysql.connector
 
-from trell.utils import LogFormatter
-LogFormatter.apply()
+# from trell.utils import LogFormatter
+# LogFormatter.apply()
  
 class MySQL:
 
